<?php
/**
 * $content_width is required even though this is a variable-width theme
 */
if ( ! isset( $dw_cybex_content_width ) ) {
	$dw_cybex_content_width = 400;
}

if ( ! function_exists( 'dw_cybex_setup' ) ) :
	function dw_cybex_setup() {
		load_theme_textdomain( 'dw-cybex', get_template_directory() . '/languages' );
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 277,
				'width'       => 851,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);

		add_theme_support( 'title-tag' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'customize-selective-recybex-widgets' );
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 150, 150 );
		add_image_size( 'dw-cybex-single-post-thumbnail', 9999, 9999 );
		add_image_size( 'dw-cybex-homepage-featured', 350, 350 );
		add_theme_support(
			'starter-content',
			array(
				'widgets' => array(
					'left-sidebar'  => array(
						array(
							'text',
							array(
								'title' => esc_html__( 'First Sidebar', 'dw-cybex' ),
								'text'  => _x( 'This is some text in the first sidebar.', 'Theme Starter Content', 'dw-cybex' ),
							),
						),
					),
					'right-sidebar' => array(
						array(
							'text',
							array(
								'title' => esc_html__( 'Second Sidebar', 'dw-cybex' ),
								'text'  => _x( 'This is some text in the second sidebar.', 'Theme Starter Content', 'dw-cybex' ),
							),
						),
					),
					'center-block'  => array(
						array(
							'text',
							array(
								'title' => esc_html__( 'Center Block', 'dw-cybex' ),
								'text'  => _x( 'This is some text in the center block.', 'Theme Starter Content', 'dw-cybex' ),
							),
						),
					),
				),
			)
		);
	}
	add_action( 'after_setup_theme', 'dw_cybex_setup' );
endif;

if ( ! function_exists( 'dw_cybex_register_menu' ) ) :
	function dw_cybex_register_menu() {
		register_nav_menus(
			array(
				'top_header_menu' => esc_html__( 'Top Header Menu', 'dw-cybex' ),
			)
		);
	}
	add_action( 'init', 'dw_cybex_register_menu' );
endif;

if ( ! function_exists( 'dw_cybex_stylesheet' ) ) :
	function dw_cybex_stylesheet() {
		wp_enqueue_style( 'dw-cybex-style', get_stylesheet_directory_uri() . '/style.css', array(), wp_get_theme()->version );
	}
	add_action( 'wp_enqueue_scripts', 'dw_cybex_stylesheet' );
endif;

if ( ! function_exists( 'dw_cybex_sidebars' ) ) :
	// register the sidebars
	function dw_cybex_sidebars() {
		register_sidebar(
			array(
				'name' => __( 'Left Sidebar 1', 'dw-cybex' ),
				'id'   => 'left-sidebar',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Center Block 1', 'dw-cybex' ),
				'id'   => 'center-block',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Right Sidebar 1', 'dw-cybex' ),
				'id'   => 'right-sidebar',
			)
		);
	}
	add_action( 'widgets_init', 'dw_cybex_sidebars' );
endif;

// display information about a post under the post title
if ( ! function_exists( 'dw_cybex_post_meta' ) ) :
	function dw_cybex_post_meta() {
		echo '<div class="meta">';
		if ( get_post_type() === 'page' ) :
			printf(
				/* translators: %s = author */
				esc_html__( 'Posted by %s', 'dw-cybex' ),
				get_the_author()
			);
		elseif ( has_category() ) :
			printf(
				/* translators: %1$s = date, %2$s = categories, %3$s = author */
				esc_html__( 'Posted on %1$s in %2$s by %3$s', 'dw-cybex' ),
				get_the_date(),
				wp_kses_post( get_the_category_list( ',' ) ),
				get_the_author()
			);
		else :
			printf(
				/* translators: %1$s = date, %2$s = author */
				esc_html__( 'Posted on %1$s by %2$s', 'dw-cybex' ),
				get_the_date(),
				get_the_author()
			);
		endif;
		edit_post_link( _x( 'Edit', 'verb', 'dw-cybex' ), ' | ' );
		if ( get_post_type() !== 'page' && has_tag() ) :
			echo '<br>';
			the_tags();
		endif;
		echo '</div>';
	}
endif;

// change the archive title to show the search query when showing the archive title on a search result page.
if ( ! function_exists( 'dw_cybex_search_title' ) ) :
	function dw_cybex_search_title( $title ) {
		if ( is_search() ) {
			/* translators: %s = search query */
			$title = sprintf( __( 'Search: %s', 'dw-cybex' ), get_search_query() );
		}
		return $title;
	}
	add_filter( 'get_the_archive_title', 'dw_cybex_search_title' );
endif;

/**
 * Enqueue scripts
 */
function dw_cybex_enqueue_scripts() {
	wp_enqueue_script( 'dw-cybex-header-clock', get_template_directory_uri() . '/js/dw-cybex-header-clock.js', array(), wp_get_theme()->version, true );
	wp_enqueue_script( 'dw-cybex-top-button', get_template_directory_uri() . '/js/dw-cybex-top-button.js', array(), wp_get_theme()->version, true );
	wp_enqueue_script( 'dw-cybex-navigation', get_template_directory_uri() . '/js/dw-cybex-navigation.js', array( 'jquery' ), '20141205', true );
}
add_action( 'wp_enqueue_scripts', 'dw_cybex_enqueue_scripts' );

require get_template_directory() . '/inc/header-nav.php';
require get_template_directory() . '/inc/social-text-bar.php';
require get_template_directory() . '/inc/footer-content.php';
require get_template_directory() . '/inc/color-select.php';
require get_template_directory() . '/inc/upsell.php';
require get_template_directory() . '/assets/essential.php';
require get_template_directory() . '/assets/font.php';
